"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = errorHandler;

var _errors = _interopRequireDefault(require("@feathersjs/errors"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function errorHandler(error) {
  let feathersError = error;

  if (error.code === 'SQLITE_ERROR') {
    switch (error.errno) {
      case 1:
      case 8:
      case 18:
      case 19:
      case 20:
        feathersError = new _errors.default.BadRequest(error);
        break;

      case 2:
        feathersError = new _errors.default.Unavailable(error);
        break;

      case 3:
      case 23:
        feathersError = new _errors.default.Forbidden(error);
        break;

      case 12:
        feathersError = new _errors.default.NotFound(error);
        break;

      default:
        feathersError = new _errors.default.GeneralError(error);
        break;
    }

    throw feathersError;
  } // Objection validation error


  if (error.statusCode) {
    switch (error.statusCode) {
      case 400:
        feathersError = new _errors.default.BadRequest(error.data);
        break;

      case 401:
        feathersError = new _errors.default.NotAuthenticated(error.data);
        break;

      case 402:
        feathersError = new _errors.default.PaymentError(error.data);
        break;

      case 403:
        feathersError = new _errors.default.Forbidden(error.data);
        break;

      case 404:
        feathersError = new _errors.default.NotFound(error.data);
        break;

      case 405:
        feathersError = new _errors.default.MethodNotAllowed(error.data);
        break;

      case 406:
        feathersError = new _errors.default.NotAcceptable(error.data);
        break;

      case 408:
        feathersError = new _errors.default.Timeout(error.data);
        break;

      case 409:
        feathersError = new _errors.default.Conflict(error.data);
        break;

      case 422:
        feathersError = new _errors.default.Unprocessable(error.data);
        break;

      case 501:
        feathersError = new _errors.default.NotImplemented(error.data);
        break;

      case 503:
        feathersError = new _errors.default.Unavailable(error.data);
        break;

      case 500:
      default:
        feathersError = new _errors.default.GeneralError(error);
    }

    throw feathersError;
  } // Postgres error code
  // TODO
  // Properly detect postgres error


  if (typeof error.code === 'string') {
    const pgerror = error.code.substring(0, 2);

    switch (pgerror) {
      case '28':
      case '42':
        feathersError = new _errors.default.Forbidden(error);
        break;

      case '20':
      case '21':
      case '22':
      case '23':
        feathersError = new _errors.default.BadRequest(error);
        break;

      default:
        feathersError = new _errors.default.GeneralError(error);
    }

    throw feathersError;
  }

  throw feathersError;
}

module.exports = exports["default"];